var bundle = (function (external) {
	'use strict';



	return external.value;

})(external);
